@@ -1,5 +1,5 @@
 # MIT licensed
-# Copyright (c) 2013-2017 lilydjwg <lilydjwg@gmail.com>, et al.
+# Copyright (c) 2013-2020 lilydjwg <lilydjwg@gmail.com>, et al.
 
 import shutil
 import pytest
@@ -8,7 +8,12 @@ pytestmark = [pytest.mark.asyncio,
                                  reason="requires pacman command")]
 
 async def test_pacman(get_version):
-    assert await get_version("ipw2100-fw", {"pacman": None}) == "1.3-10"
+    assert await get_version("ipw2100-fw", {
+        "source": "pacman",
+    }) == "1.3-10"
 
 async def test_pacman_strip_release(get_version):
-    assert await get_version("ipw2100-fw", {"pacman": None, "strip-release": 1}) == "1.3"
+    assert await get_version("ipw2100-fw", {
+        "source": "pacman",
+        "strip_release": 1,
+    }) == "1.3"
